@@ -1,15 +1,14 @@
 """Jenks, a Jenkins command line tool.
 Usage:
+  jenks docs
   jenks [<keys>] [-c | -l | -t]
-  jenks (-d | --docs)
   jenks (-h | --help)
 
 Options:
   -c, --console   print console information
-  -d, --docs      list full documentation
   -l, --list      list the jobs
   -t, --trigger   trigger jobs
-  -h, --help      print this help guide. use `jenks -d` for a full page of documentation
+  -h, --help      print this help guide. use `jenks docs` for a full page of documentation
 """
 import signal
 import sys
@@ -17,7 +16,7 @@ import sys
 from docopt import docopt
 from .data import get_configuration, JenksData
 from .command import List, Console, Status, Trigger
-from .docs import DOCS
+from .docs import DOCS, README_CONTENT
 
 
 def signal_handler(signal, frame):
@@ -29,16 +28,25 @@ ARGUMENT_COMMANDS = [List, Console, Trigger]
 
 def main(argv=sys.argv[1:]):
     signal.signal(signal.SIGINT, signal_handler)
-    options = docopt(__doc__, argv=argv, version="jenks 0.1")
-    if options['--docs']:
-        print(DOCS.format(__doc__))
+    options = docopt(__doc__, argv=argv, version="jenks 0.2")
+    if options['docs']:
+        print(DOCS.format(
+            readme=README_CONTENT,
+            usage=__doc__
+        ))
         sys.exit(0)
     try:
         data = JenksData(get_configuration())
+
         inp = None
         if not sys.stdin.isatty():
             inp = sys.stdin.read().strip().replace('\n', '')
-        keys = options['<keys>'] or inp or data.job_keys()
+        keys = options['<keys>'] or inp 
+        if keys:
+            keys = keys.lstrip(':')
+        else:
+            keys = data.job_keys()
+
         command = DEFAULT_COMMAND
         for cmd in ARGUMENT_COMMANDS:
             if options[cmd.argument]:
